.. _spkg_tomli:

tomli: A lil' TOML parser
=========================

Description
-----------

A lil' TOML parser

License
-------

Upstream Contact
----------------

https://pypi.org/project/tomli/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    2.3.0

version_requirements.txt::

    tomli

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install tomli

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i tomli

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install tomli

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-tomli

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/tomli

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-tomli

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-tomli


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
